@@ -6,6 +6,7 @@
 
 import unittest
 import tensorflow as tf
+from tensorflow.keras.utils import plot_model
 from datasets import TextlineParser
 from datasets import TFDataset
 from datasets.utils import TokenDicts, DataSchema
@@ -33,7 +34,8 @@ class GRUDecoder(tf.keras.Model):
                                        recurrent_initializer='glorot_uniform')
         self.fc = tf.keras.layers.Dense(vocab_size)
 
-    def call(self, dec_input, dec_hidden, enc_output):
+    def call(self, inputs):
+        dec_input, dec_hidden = inputs
         # x 在通过嵌入层后的形状 == （批大小，1，嵌入维度）
         decoder_embedding = self.embedding(dec_input)
 
@@ -41,11 +43,11 @@ class GRUDecoder(tf.keras.Model):
         decoder_outputs, decoder_state = s
 
         # 输出的形状 == （批大小 * 1，隐藏层大小）
-        output = tf.reshape(decoder_outputs, (-1, decoder_outputs.shape[2]))
+        #output = tf.reshape(decoder_outputs, (-1, decoder_outputs.shape[2]))
 
         # 输出的形状 == （批大小，vocab）
-        x = self.fc(output)
-        return x, decoder_state, None
+        x = self.fc(decoder_outputs)
+        return x, decoder_state
 
 
 class GRUEncoder(tf.keras.Model):
@@ -61,11 +63,15 @@ class GRUEncoder(tf.keras.Model):
                                        return_state=True,
                                        recurrent_initializer='glorot_uniform')
 
-    def call(self, x: np.ndarray, hidden: np.ndarray) -> np.ndarray:
+    def call(self, x: np.ndarray) -> np.ndarray:
         x = self.embedding(x)
-        output, state = self.gru(x, initial_state=hidden)
+        #print('x',x)
+        output, state = self.gru(x)
         return output, state
 
+    def get_inputs(self):
+        return tf.keras.layers.Input(shape=(None,), dtype= tf.int32)
+
 
 class TestDatasets(unittest.TestCase):
     """Tests for `datasets` package."""
@@ -92,14 +98,14 @@ class TestDatasets(unittest.TestCase):
         data_field_list.append(DataSchema(name='query', processor='to_tokenid',
                                           dtype='int32', shape=(None,), is_with_len=False, token_dict_name='query'))
         label_field = DataSchema(
-            name='label', processor='to_tokenid', dtype='int32', shape=(None,), is_with_len=False, token_dict_name='query')
+            name='label', processor='to_tokenid', dtype='int32', shape=(None,), is_with_len=True, token_dict_name='query')
         parser = TextlineParser(token_dicts, data_field_list, label_field)
-        generator = TFDataset(parser=parser, file_path='tests/data', file_suffix='text_seq2seq.input')
-        dataset = generator.generate_dataset(batch_size=12, num_epochs=60, is_shuffle=False)
-        for (batchs, (inputs, targets)) in enumerate(dataset):
-            print('bacths', batchs, 'inputs', inputs, 'targets', targets)
-            if batchs > 3:
-                break
+        generator = TFDataset(parser=parser, file_path='tests/data', file_suffix='text_seq2seq.input1')
+        dataset = generator.generate_dataset(batch_size=64, num_epochs=900, is_shuffle=False)
+        #for (batchs, (inputs, targets)) in enumerate(dataset):
+        #    #print('bacths', batchs, 'inputs', inputs, 'targets', targets)
+        #    if batchs > 3:
+        #        break
         query_vocab_size = token_dicts.dict_size_by_name('query')
         print('query_size', query_vocab_size)
         print('<s>', token_dicts.to_id('query', '<s>'))
@@ -108,9 +114,19 @@ class TestDatasets(unittest.TestCase):
         decoder = GRUDecoder(64, query_vocab_size, query_vocab_size)
 
         optimizer = tf.keras.optimizers.Adam()
-        model = Seq2seqModel(optimizer, seq2seq_cross_entropy_loss, encoder, decoder)
-        # model.summary()
-        model.fit(dataset, 12, epochs=8, bar_step=10)
+        model = Seq2seqModel(optimizer, seq2seq_cross_entropy_loss, encoder, decoder, feature_fields=data_field_list, label_fields=[label_field])
+        #model.model.summary()
+        #plot_model(model.model, 'model.png', show_shapes=True)
+        model.model.load_weights('model.h5')
+        model.fit(dataset, 64, epochs=80, bar_step=20)
+        model.model.save_weights('model.h5')
+        """
+        for (batchs, (inputs, targets)) in enumerate(dataset):
+            result = model.predict(inputs)
+            print('target', targets, 'predicts', result)
+            if batchs > 1:
+                break
+        """
 
 
 if __name__ == '__main__':
